**Almir** is a `bacula <http://www.bacula.org>`_ web interface for administrators written in Python.
It is designed with simplicity in mind, although backup management is never simple.

It is named after `Almir Karič <http://www.kiberpipa.org/sl/news/11315/almirju-v-spomin/>`_,
a fellow developer from **Slovenia**, whose dream was to live in San Francisco.
Two years after he moved, he died in a car crash. This is his gift for eternity.

**Almir** is open source software licensed under **GPL v3**,
started by `Domen Kožar <http://www.domenkozar.com>`_ in 2011.
